@@ -31,6 +31,7 @@
 #endif
 #include <unistd.h>
 
+#define INCLUDED_BY_MAIN_MODULE 1
 #include "g13-syshelp.h"
 
 #include <gcrypt.h>
@@ -324,7 +325,7 @@ main ( int argc, char **argv)
   if (configname)
     {
       configlineno = 0;
-      configfp = fopen (configname, "r");
+      configfp = gnupg_fopen (configname, "r");
       if (!configfp)
         {
           if (default_config)
@@ -587,7 +588,7 @@ g13_syshelp_i_know_what_i_am_doing (void)
   char *fname;
 
   fname = make_filename (gnupg_sysconfdir (), yesfile, NULL);
-  if (access (fname, F_OK))
+  if (gnupg_access (fname, F_OK))
     {
       log_info ("*******************************************************\n");
       log_info ("* The G13 support for DM-Crypt is new and not matured.\n");
